pub struct ScannerBuilder { /* private fields */ }Expand description
A builder type to parameterize a Scanner.
Implementations
Sourceimpl ScannerBuilder
impl ScannerBuilder
Sourcepub fn scan<S: AsRef<str> + Clone>(&self, sequence: S) -> Scanner<S> ⓘ
pub fn scan<S: AsRef<str> + Clone>(&self, sequence: S) -> Scanner<S> ⓘ
Scan the provided sequence for CRISPR regions iteratively.
The sequence can be provided as any string view that also implements
Clone. This allows several smart pointers to be passed (&str,
Rc<str>, Arc<str>, etc.). The actual sequence object however
will be cloned into the result Crispr, so make sure it implements
a cheap Clone, and avoid passing a String.
Sourcepub fn min_repeat_count(&mut self, min_repeat_count: usize) -> &mut Self
pub fn min_repeat_count(&mut self, min_repeat_count: usize) -> &mut Self
Set the minimum repeat number for CRISPR detection.
Sourcepub fn min_repeat_length(&mut self, min_repeat_length: usize) -> &mut Self
pub fn min_repeat_length(&mut self, min_repeat_length: usize) -> &mut Self
Set the minimum length for each CRISPR repeat.
Sourcepub fn max_repeat_length(&mut self, max_repeat_length: usize) -> &mut Self
pub fn max_repeat_length(&mut self, max_repeat_length: usize) -> &mut Self
Set the maximum length for each CRISPR repeat.
Sourcepub fn min_spacer_length(&mut self, min_spacer_length: usize) -> &mut Self
pub fn min_spacer_length(&mut self, min_spacer_length: usize) -> &mut Self
Set the minimum length for each CRISPR spacer.
Sourcepub fn max_spacer_length(&mut self, max_spacer_length: usize) -> &mut Self
pub fn max_spacer_length(&mut self, max_spacer_length: usize) -> &mut Self
Set the maximum length for each CRISPR spacer.